==> aom-docs-3.1.2-1-armv7h.pkg.tar.xz: usr/share/doc/aom/block_8h.js <==
var block_8h =
[
    [ "SuperBlockEnc", "structSuperBlockEnc.html", "structSuperBlockEnc" ],
    [ "WinnerModeStats", "structWinnerModeStats.html", "structWinnerModeStats" ],
    [ "macroblock_plane", "structmacroblock__plane.html", "structmacroblock__plane" ],
    [ "LV_MAP_COEFF_COST", "structLV__MAP__COEFF__COST.html", "structLV__MAP__COEFF__COST" ],
    [ "LV_MAP_EOB_COST", "structLV__MAP__EOB__COST.html", "structLV__MAP__EOB__COST" ],
    [ "CB_COEFF_BUFFER", "structCB__COEFF__BUFFER.html", "structCB__COEFF__BUFFER" ],
    [ "MB_MODE_INFO_EXT", "structMB__MODE__INFO__EXT.html", "structMB__MODE__INFO__EXT" ],
    [ "MB_MODE_INFO_EXT_FRAME", "structMB__MODE__INFO__EXT__FRAME.html", "structMB__MODE__INFO__EXT__FRAME" ],
    [ "MB_RD_INFO", "structMB__RD__INFO.html", "structMB__RD__INFO" ],
    [ "MB_RD_RECORD", "structMB__RD__RECORD.html", "structMB__RD__RECORD" ],
    [ "TXB_RD_INFO", "structTXB__RD__INFO.html", "structTXB__RD__INFO" ],
    [ "TXB_RD_RECORD", "structTXB__RD__RECORD.html", "structTXB__RD__RECORD" ],
    [ "COMP_RD_STATS", "structCOMP__RD__STATS.html", "structCOMP__RD__STATS" ],
    [ "OBMCBuffer", "structOBMCBuffer.html", "structOBMCBuffer" ],
    [ "PALETTE_BUFFER", "structPALETTE__BUFFER.html", "structPALETTE__BUFFER" ],
    [ "CompoundTypeRdBuffers", "structCompoundTypeRdBuffers.html", "structCompoundTypeRdBuffers" ],
    [ "PartitionSearchInfo", "structPartitionSearchInfo.html", "structPartitionSearchInfo" ],
    [ "TxfmSearchParams", "structTxfmSearchParams.html", "structTxfmSearchParams" ],
    [ "TxbRdRecords", "structTxbRdRecords.html", "structTxbRdRecords" ],
    [ "TxfmSearchInfo", "structTxfmSearchInfo.html", "structTxfmSearchInfo" ],
    [ "ModeCosts", "structModeCosts.html", "structModeCosts" ],
    [ "MvCosts", "structMvCosts.html", "structMvCosts" ],
    [ "IntraBCMVCosts", "structIntraBCMVCosts.html", "structIntraBCMVCosts" ],
    [ "CoeffCosts", "structCoeffCosts.html", "structCoeffCosts" ],
    [ "WARP_SAMPLE_INFO", "structWARP__SAMPLE__INFO.html", "structWARP__SAMPLE__INFO" ],
    [ "macroblock", "structmacroblock.html", "structmacroblock" ],
    [ "MIN_TPL_BSIZE_1D", "block_8h.html#ae0a195ea38f0a04ad9a9d6d7ed5bb754", null ],
    [ "MAX_TPL_BLK_IN_SB", "block_8h.html#a73de00e232811ea3f0290dcc425f86d5", null ],
    [ "MAX_WINNER_MODE_COUNT_INTRA", "block_8h.html#ab657b1844dfce1e763e658761bb0952c", null ],
    [ "MAX_WINNER_MODE_COUNT_INTER", "block_8h.html#a602ec0e36e0a86c78c15fe547c275e1f", null ],
    [ "RD_RECORD_BUFFER_LEN", "block_8h.html#a8c18014b69f341bf169c4a5656ee2978", null ],
    [ "TX_SIZE_RD_RECORD_BUFFER_LEN", "block_8h.html#ad4666c85680e16e181fe9b46c1957274", null ],
    [ "MAX_COMP_RD_STATS", "block_8h.html#a6e06ec17c5b54de9fd8d829fb2a305b7", null ],
    [ "MACROBLOCK_PLANE", "block_8h.html#aa775a8f85de55be3f4c2e39285d706c9", null ],
    [ "MACROBLOCK", "block_8h.html#aaaf8a99ac7b3d643d9b95ea1da93f6c2", null ]
];

==> aom-docs-3.3.0-1-armv7h.pkg.tar.xz: usr/share/doc/aom/block_8h.js <==
var block_8h =
[
    [ "SuperBlockEnc", "structSuperBlockEnc.html", "structSuperBlockEnc" ],
    [ "WinnerModeStats", "structWinnerModeStats.html", "structWinnerModeStats" ],
    [ "macroblock_plane", "structmacroblock__plane.html", "structmacroblock__plane" ],
    [ "LV_MAP_COEFF_COST", "structLV__MAP__COEFF__COST.html", "structLV__MAP__COEFF__COST" ],
    [ "LV_MAP_EOB_COST", "structLV__MAP__EOB__COST.html", "structLV__MAP__EOB__COST" ],
    [ "CB_COEFF_BUFFER", "structCB__COEFF__BUFFER.html", "structCB__COEFF__BUFFER" ],
    [ "MB_MODE_INFO_EXT", "structMB__MODE__INFO__EXT.html", "structMB__MODE__INFO__EXT" ],
    [ "MB_MODE_INFO_EXT_FRAME", "structMB__MODE__INFO__EXT__FRAME.html", "structMB__MODE__INFO__EXT__FRAME" ],
    [ "MB_RD_INFO", "structMB__RD__INFO.html", "structMB__RD__INFO" ],
    [ "MB_RD_RECORD", "structMB__RD__RECORD.html", "structMB__RD__RECORD" ],
    [ "COMP_RD_STATS", "structCOMP__RD__STATS.html", "structCOMP__RD__STATS" ],
    [ "OBMCBuffer", "structOBMCBuffer.html", "structOBMCBuffer" ],
    [ "PALETTE_BUFFER", "structPALETTE__BUFFER.html", "structPALETTE__BUFFER" ],
    [ "CompoundTypeRdBuffers", "structCompoundTypeRdBuffers.html", "structCompoundTypeRdBuffers" ],
    [ "PartitionSearchInfo", "structPartitionSearchInfo.html", "structPartitionSearchInfo" ],
    [ "TxfmSearchParams", "structTxfmSearchParams.html", "structTxfmSearchParams" ],
    [ "TxfmSearchInfo", "structTxfmSearchInfo.html", "structTxfmSearchInfo" ],
    [ "ModeCosts", "structModeCosts.html", "structModeCosts" ],
    [ "MvCosts", "structMvCosts.html", "structMvCosts" ],
    [ "IntraBCMVCosts", "structIntraBCMVCosts.html", "structIntraBCMVCosts" ],
    [ "CoeffCosts", "structCoeffCosts.html", "structCoeffCosts" ],
    [ "WARP_SAMPLE_INFO", "structWARP__SAMPLE__INFO.html", "structWARP__SAMPLE__INFO" ],
    [ "macroblock", "structmacroblock.html", "structmacroblock" ],
    [ "MIN_TPL_BSIZE_1D", "block_8h.html#ae0a195ea38f0a04ad9a9d6d7ed5bb754", null ],
    [ "MAX_TPL_BLK_IN_SB", "block_8h.html#a73de00e232811ea3f0290dcc425f86d5", null ],
    [ "MAX_WINNER_MODE_COUNT_INTRA", "block_8h.html#ab657b1844dfce1e763e658761bb0952c", null ],
    [ "MAX_WINNER_MODE_COUNT_INTER", "block_8h.html#a602ec0e36e0a86c78c15fe547c275e1f", null ],
    [ "RD_RECORD_BUFFER_LEN", "block_8h.html#a8c18014b69f341bf169c4a5656ee2978", null ],
    [ "MAX_TX_TYPE_PROB", "block_8h.html#a98e449b5753918529e949cfa37abd5a3", null ],
    [ "MAX_COMP_RD_STATS", "block_8h.html#a6e06ec17c5b54de9fd8d829fb2a305b7", null ],
    [ "MACROBLOCK_PLANE", "block_8h.html#aa775a8f85de55be3f4c2e39285d706c9", null ],
    [ "MACROBLOCK", "block_8h.html#aaaf8a99ac7b3d643d9b95ea1da93f6c2", null ]
];
